# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelProductExtraDataItemResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'value': 'str',
        'type': 'ExtraDataType',
        'is_public': 'bool'
    }

    attribute_map = {
        'key': 'Key',
        'value': 'Value',
        'type': 'Type',
        'is_public': 'IsPublic'
    }

    def __init__(self, key=None, value=None, type=None, is_public=None, local_vars_configuration=None):  # noqa: E501
        """ChannelProductExtraDataItemResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._value = None
        self._type = None
        self._is_public = None
        self.discriminator = None

        self.key = key
        self.value = value
        if type is not None:
            self.type = type
        if is_public is not None:
            self.is_public = is_public

    @property
    def key(self):
        """Gets the key of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Name of the extra data field.  # noqa: E501

        :return: The key of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ChannelProductExtraDataItemResponse.

        Name of the extra data field.  # noqa: E501

        :param key: The key of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type key: str
        """
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) > 100):
            raise ValueError("Invalid value for `key`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                key is not None and len(key) < 0):
            raise ValueError("Invalid value for `key`, length must be greater than or equal to `0`")  # noqa: E501

        self._key = key

    @property
    def value(self):
        """Gets the value of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Value of the extra data field.  # noqa: E501

        :return: The value of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ChannelProductExtraDataItemResponse.

        Value of the extra data field.  # noqa: E501

        :param value: The value of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type value: str
        """

        self._value = value

    @property
    def type(self):
        """Gets the type of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Type of the extra data field.  # noqa: E501

        :return: The type of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: ExtraDataType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChannelProductExtraDataItemResponse.

        Type of the extra data field.  # noqa: E501

        :param type: The type of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type type: ExtraDataType
        """

        self._type = type

    @property
    def is_public(self):
        """Gets the is_public of this ChannelProductExtraDataItemResponse.  # noqa: E501

        Add this field to the export of the product feed to the channel.  # noqa: E501

        :return: The is_public of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this ChannelProductExtraDataItemResponse.

        Add this field to the export of the product feed to the channel.  # noqa: E501

        :param is_public: The is_public of this ChannelProductExtraDataItemResponse.  # noqa: E501
        :type is_public: bool
        """

        self._is_public = is_public

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelProductExtraDataItemResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelProductExtraDataItemResponse):
            return True

        return self.to_dict() != other.to_dict()
