# coding: utf-8

"""
    ChannelEngine Channel API

    ChannelEngine API for channels  # noqa: E501

    The version of the OpenAPI document: 2.9.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from channelengine_channel_api_client.configuration import Configuration


class ChannelProcessedChangesRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created': 'list[ChannelProductReferencesRequest]',
        'updated': 'list[str]',
        'removed': 'list[str]'
    }

    attribute_map = {
        'created': 'Created',
        'updated': 'Updated',
        'removed': 'Removed'
    }

    def __init__(self, created=None, updated=None, removed=None, local_vars_configuration=None):  # noqa: E501
        """ChannelProcessedChangesRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._created = None
        self._updated = None
        self._removed = None
        self.discriminator = None

        self.created = created
        self.updated = updated
        self.removed = removed

    @property
    def created(self):
        """Gets the created of this ChannelProcessedChangesRequest.  # noqa: E501

        A collection of pairs of merchant and channel references  of the products which are successfully created. The channel references  are saved such that in subsequent calls these can be used instead of the  merchant references.  # noqa: E501

        :return: The created of this ChannelProcessedChangesRequest.  # noqa: E501
        :rtype: list[ChannelProductReferencesRequest]
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ChannelProcessedChangesRequest.

        A collection of pairs of merchant and channel references  of the products which are successfully created. The channel references  are saved such that in subsequent calls these can be used instead of the  merchant references.  # noqa: E501

        :param created: The created of this ChannelProcessedChangesRequest.  # noqa: E501
        :type created: list[ChannelProductReferencesRequest]
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this ChannelProcessedChangesRequest.  # noqa: E501

        The channel references of the products which are successfully updated.  # noqa: E501

        :return: The updated of this ChannelProcessedChangesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ChannelProcessedChangesRequest.

        The channel references of the products which are successfully updated.  # noqa: E501

        :param updated: The updated of this ChannelProcessedChangesRequest.  # noqa: E501
        :type updated: list[str]
        """

        self._updated = updated

    @property
    def removed(self):
        """Gets the removed of this ChannelProcessedChangesRequest.  # noqa: E501

        The channel references of the products which are successfully removed.  # noqa: E501

        :return: The removed of this ChannelProcessedChangesRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._removed

    @removed.setter
    def removed(self, removed):
        """Sets the removed of this ChannelProcessedChangesRequest.

        The channel references of the products which are successfully removed.  # noqa: E501

        :param removed: The removed of this ChannelProcessedChangesRequest.  # noqa: E501
        :type removed: list[str]
        """

        self._removed = removed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChannelProcessedChangesRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChannelProcessedChangesRequest):
            return True

        return self.to_dict() != other.to_dict()
